@@ -66,7 +66,7 @@ enum {
 };
 
 static void gnome_client_class_init              (GnomeClientClass *klass);
-static void gnome_client_object_init             (GnomeClient      *client);
+static void gnome_client_instance_init           (GnomeClient      *client);
 
 static void gnome_real_client_destroy            (GtkObject        *object);
 static void gnome_real_client_save_complete      (GnomeClient      *client);
@@ -86,7 +86,6 @@ static void   client_unset_config_prefix    (GnomeClient *client);
 static gchar** array_init_from_arg           (gint argc, 
 					      gchar *argv[]);
 
-static GtkObjectClass *parent_class = NULL;
 static gint client_signals[LAST_SIGNAL] = { 0 };
 
 static const char *sm_client_id_arg_name G_GNUC_UNUSED = "--sm-client-id";
@@ -586,7 +585,7 @@ client_save_yourself_callback (SmcConn   smc_conn,
   gboolean ret;
 
   if (!client_grab_widget)
-    client_grab_widget = gtk_widget_new (gtk_widget_get_type(), NULL);
+    client_grab_widget = gtk_widget_new (GTK_TYPE_WIDGET, NULL);
 
   /* The first SaveYourself after registering for the first time
    * is a special case (SM specs 7.2).
@@ -1146,39 +1145,14 @@ gnome_master_client (void)
 /*****************************************************************************/
 /* GTK-class managing functions */
 
-GtkType
-gnome_client_get_type (void)
-{
-  static GtkType client_type = 0;
-  
-  if (!client_type)
-    {
-      GtkTypeInfo client_info =
-      {
-	"GnomeClient",
-	sizeof (GnomeClient),
-	sizeof (GnomeClientClass),
-	(GtkClassInitFunc) gnome_client_class_init,
-	(GtkObjectInitFunc) gnome_client_object_init,
-	NULL,
-	NULL,
-	NULL
-      };
-
-      client_type = gtk_type_unique (gtk_object_get_type (), &client_info);
-    }
-  
-  return client_type;
-}
+GNOME_CLASS_BOILERPLATE (GnomeClient, gnome_client,
+			 GtkObject, gtk_object, GTK_TYPE_OBJECT)
 
 static void
 gnome_client_class_init (GnomeClientClass *klass)
 {
   GtkObjectClass *object_class = (GtkObjectClass*) klass;
   
-  parent_class = gtk_type_class (gtk_object_get_type ());
-  
-  
   client_signals[SAVE_YOURSELF] =
     gtk_signal_new ("save_yourself",
 		    GTK_RUN_LAST,
@@ -1240,7 +1214,7 @@ gnome_client_class_init (GnomeClientClass *klass)
 }
 
 static void
-gnome_client_object_init (GnomeClient *client)
+gnome_client_instance_init (GnomeClient *client)
 {
   client->smc_conn          = NULL;
   client->client_id         = NULL;
@@ -1386,7 +1360,7 @@ gnome_client_new_without_connection (void)
 {
   GnomeClient *client;
 
-  client= gtk_type_new (gnome_client_get_type ());
+  client = gtk_type_new (GNOME_TYPE_CLIENT);
 
   /* Preset the CloneCommand, RestartCommand and Program properties.
      FIXME: having a default would be cool, but it is probably hard to
@@ -2461,7 +2435,7 @@ gnome_client_save_dialog_show (GnomeClient *client, gint key,
   gboolean shutdown_cancelled;
 
   if (client->shutdown) 
-    gtk_dialog_add_button (dialog, _("Cancel Logout"), GTK_RESPONSE_CANCEL);
+	  gtk_dialog_add_button (dialog, _("Cancel Logout"), GTK_RESPONSE_CANCEL);
   gtk_widget_show_all (GTK_WIDGET (dialog));
   /* These are SYSTEM modal dialogs so map them above everything else */
 #if 0
