@@ -158,6 +158,8 @@ struct _GnomeClient
   gboolean            save_phase_2_requested : 1;
   gboolean            save_successfull : 1;
   gboolean            save_yourself_emitted : 1;
+
+  gpointer            reserved; /* Reserved for private struct */
 };
 
 
@@ -180,11 +182,12 @@ struct _GnomeClientClass
   void (* disconnect)         (GnomeClient        *client);
 };
 
+#define GNOME_CLIENT_MODULE gnome_client_module_info_get()
 const GnomeModuleInfo *gnome_client_module_info_get (void) G_GNUC_CONST;
+
 #define GNOME_CLIENT_PARAM_SM_CONNECT "sm-connect"
 
-/* For internal use by the gnome-libs: */
-guint        gnome_client_get_type (void) G_GNUC_CONST;
+GType        gnome_client_get_type (void) G_GNUC_CONST;
 
 /* Get the master session management client.  This master client gets
    a client id, that may be specified by the '--sm-client-id' command
