@@ -28,7 +28,7 @@
  */
 
 #include <config.h>
-#include "gnome-macros.h"
+#include <libgnome/gnome-macros.h>
 
 #include <gtk/gtkmain.h>
 #include <gtk/gtkalignment.h>
@@ -93,7 +93,7 @@ enum {
 };
 
 static void gnome_color_picker_class_init (GnomeColorPickerClass *class);
-static void gnome_color_picker_init       (GnomeColorPicker      *cp);
+static void gnome_color_picker_instance_init (GnomeColorPicker      *cp);
 static void gnome_color_picker_destroy    (GtkObject             *object);
 static void gnome_color_picker_finalize   (GObject               *object);
 static void gnome_color_picker_clicked    (GtkButton             *button);
@@ -129,7 +129,7 @@ static guint color_picker_signals[LAST_SIGNAL] = { 0 };
 static GtkTargetEntry drop_types[] = { { "application/x-color", 0, 0 } };
 
 GNOME_CLASS_BOILERPLATE (GnomeColorPicker, gnome_color_picker,
-			 GtkButton, gtk_button)
+			 GtkButton, gtk_button, GTK_TYPE_BUTTON)
 
 static void
 gnome_color_picker_class_init (GnomeColorPickerClass *class)
@@ -435,7 +435,7 @@ drag_data_get  (GtkWidget          *widget,
 }
 
 static void
-gnome_color_picker_init (GnomeColorPicker *cp)
+gnome_color_picker_instance_init (GnomeColorPicker *cp)
 {
 	GtkWidget *alignment;
 	GtkWidget *frame;
@@ -562,7 +562,7 @@ gnome_color_picker_finalize (GObject *object)
 GtkWidget *
 gnome_color_picker_new (void)
 {
-	return GTK_WIDGET (gtk_type_new (gnome_color_picker_get_type ()));
+	return GTK_WIDGET (gtk_type_new (GNOME_TYPE_COLOR_PICKER));
 }
 
 /* Callback used when the color selection dialog is destroyed */
