@@ -23,7 +23,7 @@
 */
 
 #include <config.h>
-#include "gnome-macros.h"
+#include <libgnome/gnome-macros.h>
 
 /* Must be before all other gnome includes!! */
 #include "gnome-i18nP.h"
@@ -49,7 +49,7 @@ struct _GnomeDruidPageEdgePrivate
 	GnomeCanvasItem *title_item;
 };
 
-static void gnome_druid_page_edge_init   	(GnomeDruidPageEdge		*druid_page_edge);
+static void gnome_druid_page_edge_instance_init	(GnomeDruidPageEdge		*druid_page_edge);
 static void gnome_druid_page_edge_class_init	(GnomeDruidPageEdgeClass	*klass);
 static void gnome_druid_page_edge_destroy 	(GtkObject                      *object);
 static void gnome_druid_page_edge_finalize 	(GObject                        *object);
@@ -68,7 +68,8 @@ static void gnome_druid_page_edge_prepare	(GnomeDruidPage		        *page,
 #define GDK_COLOR_TO_RGBA(color) GNOME_CANVAS_COLOR ((color).red/256, (color).green/256, (color).blue/256)
 
 GNOME_CLASS_BOILERPLATE (GnomeDruidPageEdge, gnome_druid_page_edge,
-			 GnomeDruidPage, gnome_druid_page);
+			 GnomeDruidPage, gnome_druid_page,
+			 GNOME_TYPE_DRUID_PAGE);
 
 static void
 gnome_druid_page_edge_class_init (GnomeDruidPageEdgeClass *klass)
@@ -87,7 +88,7 @@ gnome_druid_page_edge_class_init (GnomeDruidPageEdgeClass *klass)
 }
 
 static void
-gnome_druid_page_edge_init (GnomeDruidPageEdge *druid_page_edge)
+gnome_druid_page_edge_instance_init (GnomeDruidPageEdge *druid_page_edge)
 {
 	druid_page_edge->_priv = g_new0(GnomeDruidPageEdgePrivate, 1);
 
@@ -287,21 +288,21 @@ gnome_druid_page_edge_setup (GnomeDruidPageEdge *druid_page_edge)
 	fill_color = GDK_COLOR_TO_RGBA (druid_page_edge->background_color);
 	druid_page_edge->_priv->background_item =
 		gnome_canvas_item_new (gnome_canvas_root (canvas),
-				       gnome_canvas_rect_get_type (),
+				       GNOME_TYPE_CANVAS_RECT,
 				       "fill_color_rgba", fill_color,
 				       NULL);
 
 	fill_color = GDK_COLOR_TO_RGBA (druid_page_edge->textbox_color);
 	druid_page_edge->_priv->textbox_item =
 		gnome_canvas_item_new (gnome_canvas_root (canvas),
-				       gnome_canvas_rect_get_type (),
+				       GNOME_TYPE_CANVAS_RECT,
 				       "fill_color_rgba", fill_color,
 				       NULL);
 
 	fill_color = GDK_COLOR_TO_RGBA (druid_page_edge->logo_background_color);
 	druid_page_edge->_priv->logoframe_item =
 		gnome_canvas_item_new (gnome_canvas_root (canvas),
-				       gnome_canvas_rect_get_type (),
+				       GNOME_TYPE_CANVAS_RECT,
 				       "fill_color_rgba", fill_color,
 				       NULL);
 	if (druid_page_edge->logo_image == NULL) {
@@ -310,7 +311,7 @@ gnome_druid_page_edge_setup (GnomeDruidPageEdge *druid_page_edge)
 
 	druid_page_edge->_priv->top_watermark_item =
 		gnome_canvas_item_new (gnome_canvas_root (canvas),
-				       gnome_canvas_pixbuf_get_type (),
+				       GNOME_TYPE_CANVAS_PIXBUF,
 				       "x", 0.0,
 				       "y", 0.0,
 				       "x_set", TRUE,
@@ -324,7 +325,7 @@ gnome_druid_page_edge_setup (GnomeDruidPageEdge *druid_page_edge)
 
 	druid_page_edge->_priv->logo_item =
 		gnome_canvas_item_new (gnome_canvas_root (canvas),
-				       gnome_canvas_pixbuf_get_type (),
+				       GNOME_TYPE_CANVAS_PIXBUF,
 				       "x_set", TRUE,
 				       "y_set", TRUE,
 				       NULL);
@@ -335,7 +336,7 @@ gnome_druid_page_edge_setup (GnomeDruidPageEdge *druid_page_edge)
 
 	druid_page_edge->_priv->watermark_item =
 		gnome_canvas_item_new (gnome_canvas_root (canvas),
-				       gnome_canvas_pixbuf_get_type (),
+				       GNOME_TYPE_CANVAS_PIXBUF,
 				       "x_set", TRUE,
 				       "y_set", TRUE,
 				       NULL);
@@ -348,7 +349,7 @@ gnome_druid_page_edge_setup (GnomeDruidPageEdge *druid_page_edge)
 	fill_color = GDK_COLOR_TO_RGBA (druid_page_edge->title_color);
 	druid_page_edge->_priv->title_item =
 		gnome_canvas_item_new (gnome_canvas_root (canvas),
-				       gnome_canvas_text_get_type (),
+				       GNOME_TYPE_CANVAS_TEXT,
 				       "text", druid_page_edge->title,
 				       "fill_color_rgba", fill_color,
 				       "fontset", _("-adobe-helvetica-bold-r-normal-*-*-180-*-*-p-*-*-*,*-r-*"),
@@ -357,7 +358,7 @@ gnome_druid_page_edge_setup (GnomeDruidPageEdge *druid_page_edge)
 	fill_color = GDK_COLOR_TO_RGBA (druid_page_edge->text_color);
 	druid_page_edge->_priv->text_item =
 		gnome_canvas_item_new (gnome_canvas_root (canvas),
-				       gnome_canvas_text_get_type (),
+				       GNOME_TYPE_CANVAS_TEXT,
 				       "text", druid_page_edge->text,
 				       "justification", GTK_JUSTIFY_LEFT,
 				       "fontset", _("-adobe-helvetica-medium-r-normal-*-*-120-*-*-p-*-*-*,*-r-*"),
@@ -429,7 +430,7 @@ gnome_druid_page_edge_new (GnomeEdgePosition position)
 	g_return_val_if_fail (position >= GNOME_EDGE_START &&
 			      position < GNOME_EDGE_LAST, NULL);
 
-	retval = gtk_type_new (gnome_druid_page_edge_get_type ());
+	retval = gtk_type_new (GNOME_TYPE_DRUID_PAGE_EDGE);
 
 	gnome_druid_page_edge_construct (retval,
 					 position,
@@ -461,7 +462,7 @@ gnome_druid_page_edge_new_aa (GnomeEdgePosition position)
 	g_return_val_if_fail (position >= GNOME_EDGE_START &&
 			      position < GNOME_EDGE_LAST, NULL);
 
-	retval = gtk_type_new (gnome_druid_page_edge_get_type ());
+	retval = gtk_type_new (GNOME_TYPE_DRUID_PAGE_EDGE);
 
 	gnome_druid_page_edge_construct (retval,
 					 position,
@@ -506,7 +507,7 @@ gnome_druid_page_edge_new_with_vals (GnomeEdgePosition position,
 	g_return_val_if_fail (position >= GNOME_EDGE_START &&
 			      position < GNOME_EDGE_LAST, NULL);
 
-	retval = gtk_type_new (gnome_druid_page_edge_get_type ());
+	retval = gtk_type_new (GNOME_TYPE_DRUID_PAGE_EDGE);
 
 	gnome_druid_page_edge_construct (retval,
 					 position,
