@@ -29,7 +29,7 @@
  */
 
 #include <config.h>
-#include "gnome-macros.h"
+#include <libgnome/gnome-macros.h>
 
 /* Must be before all other gnome includes!! */
 #include "gnome-i18nP.h"
@@ -43,7 +43,8 @@
 
 #include <gconf/gconf-client.h>
 #include <libgnome/gnome-program.h>
-#include <libgnome/gnome-gconf.h>
+
+#include "gnome-gconf-ui.h"
 
 #include "gnome-entry.h"
 
@@ -86,16 +87,19 @@ static void gnome_entry_set_property (GObject        *object,
 				      const GValue   *value,
 				      GParamSpec     *pspec);
 static void gnome_entry_editable_init (GtkEditableClass *iface);
+static void gnome_entry_load_history (GnomeEntry *gentry);
+static void gnome_entry_save_history (GnomeEntry *gentry);
 
 static char *build_gconf_key (GnomeEntry *gentry);
 
 /* Note, can't use boilerplate with interfaces yet,
  * should get sorted out */
 static GtkComboClass *parent_class = NULL;
-GtkType
+GType
 gnome_entry_get_type (void)
 {
-	static GtkType object_type = 0;
+	static GType object_type = 0;
+
 	if (object_type == 0) {
 		GtkType type_of_parent;
 		static const GtkTypeInfo object_info = {
@@ -114,7 +118,7 @@ gnome_entry_get_type (void)
 			NULL,			                         /* interface_finalize */
 			NULL			                         /* interface_data */
 		};
-		type_of_parent = gtk_combo_get_type ();
+		type_of_parent = GTK_TYPE_COMBO;
 		object_type = gtk_type_unique (type_of_parent, &object_info);
 		parent_class = gtk_type_class (type_of_parent);
 
@@ -331,7 +335,7 @@ gnome_entry_finalize (GObject *object)
 
 	gentry = GNOME_ENTRY (object);
 
-	gnome_gconf_lazy_init ();
+	gnomeui_gconf_lazy_init ();
 	client = gconf_client_get_default ();
 	key = build_gconf_key (gentry);
 	gconf_client_remove_dir (client, key, NULL);
@@ -398,7 +402,7 @@ gnome_entry_set_history_id (GnomeEntry *gentry, const gchar *history_id)
 
 	/* Register with gconf */
 	key = build_gconf_key (gentry);
-	gnome_gconf_lazy_init ();
+	gnomeui_gconf_lazy_init ();
 	client = gconf_client_get_default ();
 
 	gconf_client_add_dir (client,
@@ -631,7 +635,7 @@ gnome_entry_load_history (GnomeEntry *gentry)
 
 	key = build_gconf_key (gentry);
 
-	gnome_gconf_lazy_init ();
+	gnomeui_gconf_lazy_init ();
 	client = gconf_client_get_default ();
 	
 	gconf_items = gconf_client_get_list (client, key, GCONF_VALUE_STRING, NULL);
@@ -678,7 +682,7 @@ check_for_duplicates (GSList *gconf_items,
 
 	for (; gconf_items; gconf_items = gconf_items->next) {
 		
-		if (strcmp (gconf_items->data, item->text) == 0) {
+		if (strcmp ((gchar *) gconf_items->data, item->text) == 0) {
 			return FALSE;
 		}
 	}
@@ -704,7 +708,7 @@ gnome_entry_save_history (GnomeEntry *gentry)
 		return;
 
 	key = build_gconf_key (gentry);
-	gnome_gconf_lazy_init ();
+	gnomeui_gconf_lazy_init ();
 	client = gconf_client_get_default ();
 
 	gconf_items = NULL;
