@@ -77,7 +77,7 @@ struct _GnomeEntryClass {
 };
 
 
-guint        gnome_entry_get_type         (void) G_GNUC_CONST;
+GType        gnome_entry_get_type         (void) G_GNUC_CONST;
 GtkWidget   *gnome_entry_new              (const gchar *history_id);
 
 /* for language bindings and subclassing, use gnome_entry_new */
@@ -102,8 +102,6 @@ void         gnome_entry_prepend_history  (GnomeEntry  *gentry,
 void         gnome_entry_append_history   (GnomeEntry  *gentry,
 					   gboolean     save,
 					   const gchar *text);
-void         gnome_entry_load_history     (GnomeEntry  *gentry);
-void         gnome_entry_save_history     (GnomeEntry  *gentry);
 void         gnome_entry_clear_history    (GnomeEntry  *gentry);
 
 G_END_DECLS
