@@ -30,30 +30,29 @@
  * Authors: Federico Mena <federico@nuclecu.unam.mx>
  */
 #include <config.h>
-#include "gnome-macros.h"
-
-/* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <libgnome/gnome-macros.h>
 
 #include <pwd.h>
 #include <string.h>
 #include <unistd.h>
 #include <sys/param.h>
 #include <sys/types.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtksignal.h>
-#include "libgnome/gnome-util.h"
 
+/* Must be before all other gnome includes!! */
+#include "gnome-i18nP.h"
+
+#include <libgnome/gnome-util.h>
 #include "libgnomeuiP.h"
 
 #include "gnome-file-entry.h"
 
-#include <libgnomevfs/gnome-vfs-mime.h>
-
 struct _GnomeFileEntryPrivate {
 	GtkWidget *gentry;
 
@@ -105,12 +104,13 @@ enum {
 /* Note, can't use boilerplate with interfaces yet,
  * should get sorted out */
 static GtkVBoxClass *parent_class = NULL;
-GtkType
+GType
 gnome_file_entry_get_type (void)
 {
-	static GtkType object_type = 0;
+	static GType object_type = 0;
+
 	if (object_type == 0) {
-		GtkType type_of_parent;
+		GType type_of_parent;
 		static const GtkTypeInfo object_info = {
 			"GnomeFileEntry",
 			sizeof (GnomeFileEntry),
@@ -127,7 +127,7 @@ gnome_file_entry_get_type (void)
 			NULL,			                         	 /* interface_finalize */
 			NULL			                         	 /* interface_data */
 		};
-		type_of_parent = gtk_vbox_get_type ();
+		type_of_parent = GTK_TYPE_VBOX;
 		object_type = gtk_type_unique (type_of_parent, &object_info);
 		parent_class = gtk_type_class (type_of_parent);
 
@@ -343,7 +343,7 @@ browse_clicked(GnomeFileEntry *fentry)
 					 ! fentry->_priv->directory_entry);
 		p = gtk_entry_get_text (GTK_ENTRY (gnome_file_entry_gtk_entry (fentry)));
 		if(p && *p!=G_DIR_SEPARATOR && fentry->default_path) {
-			char *dp = g_concat_dir_and_file (fentry->default_path, p);
+			char *dp = g_build_filename (fentry->default_path, p, NULL);
 			gtk_file_selection_set_filename (fs, dp);
 			g_free(dp);
 		} else {
@@ -395,7 +395,7 @@ browse_clicked(GnomeFileEntry *fentry)
 
 	p = gtk_entry_get_text (GTK_ENTRY (gnome_file_entry_gtk_entry (fentry)));
 	if(p && *p!=G_DIR_SEPARATOR && fentry->default_path) {
-		char *dp = g_concat_dir_and_file (fentry->default_path, p);
+		char *dp = g_build_filename (fentry->default_path, p, NULL);
 		gtk_file_selection_set_filename (fs, dp);
 		g_free(dp);
 	} else {
@@ -615,7 +615,7 @@ gnome_file_entry_new (const char *history_id, const char *browse_dialog_title)
 {
 	GnomeFileEntry *fentry;
 
-	fentry = gtk_type_new (gnome_file_entry_get_type ());
+	fentry = gtk_type_new (GNOME_TYPE_FILE_ENTRY);
 
 	gnome_file_entry_construct (fentry, history_id, browse_dialog_title);
 	return GTK_WIDGET (fentry);
@@ -788,7 +788,7 @@ gnome_file_entry_get_full_path(GnomeFileEntry *fentry, gboolean file_must_exist)
 		p = tilde_expand (t);
 		g_free (t);
 	} else if (fentry->default_path) {
-		p = g_concat_dir_and_file (fentry->default_path, t);
+		p = g_build_filename (fentry->default_path, t, NULL);
 		g_free (t);
 		if (*p == '~') {
 			t = p;
@@ -798,7 +798,7 @@ gnome_file_entry_get_full_path(GnomeFileEntry *fentry, gboolean file_must_exist)
 	} else {
 		gchar *cwd = g_get_current_dir ();
 
-		p = g_concat_dir_and_file (cwd, t);
+		p = g_build_filename (cwd, t, NULL);
 		g_free (cwd);
 		g_free (t);
 	}
