@@ -1,5 +1,3 @@
-/* WARNING ____ IMMATURE API ____ liable to change */
-
 /* gnome-href.h
  * Copyright (C) 1998, James Henstridge <james@daa.com.au>
  * All rights reserved.
@@ -58,7 +56,7 @@ struct _GnomeHRefClass {
  * GNOME href class methods
  */
 
-GtkType gnome_href_get_type(void) G_GNUC_CONST;
+GType gnome_href_get_type(void) G_GNUC_CONST;
 GtkWidget *gnome_href_new(const gchar *url, const gchar *text);
 
 /* for bindings and subclassing, use the gnome_href_new from C */
