@@ -57,10 +57,10 @@ static void gnome_message_box_construct  (GnomeMessageBox      *messagebox,
 
 static GnomeDialogClass *parent_class;
 
-guint
+GType
 gnome_message_box_get_type (void)
 {
-	static guint message_box_type = 0;
+	static GType message_box_type = 0;
 
 	if (!message_box_type)
 	{
@@ -76,7 +76,7 @@ gnome_message_box_get_type (void)
 			NULL
 		};
 
-		message_box_type = gtk_type_unique (gnome_dialog_get_type (), &message_box_info);
+		message_box_type = gtk_type_unique (GNOME_TYPE_DIALOG, &message_box_info);
 	}
 
 	return message_box_type;
@@ -90,7 +90,7 @@ gnome_message_box_class_init (GnomeMessageBoxClass *klass)
 
 	object_class = (GtkObjectClass *)klass;
 	gobject_class = (GObjectClass *)klass;
-	parent_class = gtk_type_class (gnome_dialog_get_type ());
+	parent_class = gtk_type_class (GNOME_TYPE_DIALOG);
 
 	object_class->destroy = gnome_message_box_destroy;
 	gobject_class->finalize = gnome_message_box_finalize;
@@ -167,38 +167,24 @@ gnome_message_box_construct (GnomeMessageBox       *messagebox,
 	if (strcmp(GNOME_MESSAGE_BOX_INFO, message_box_type) == 0)
 	{
                 title_prefix = _("Information");
-		s = GNOMEUIPIXMAPDIR "/gnome-info.png";
-		if (s) {
-                        pixmap = gtk_image_new_from_file (s);
-                        g_free(s);
-                }
+		pixmap = gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
 	}
 	else if (strcmp(GNOME_MESSAGE_BOX_WARNING, message_box_type) == 0)
 	{
                 title_prefix = _("Warning");
-		s = GNOMEUIPIXMAPDIR "/gnome-warning.png";
-		if (s) {
-                        pixmap = gtk_image_new_from_file (s);
-                        g_free(s);
-                }
+		pixmap = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
+		
 	}
 	else if (strcmp(GNOME_MESSAGE_BOX_ERROR, message_box_type) == 0)
 	{
                 title_prefix = _("Error");
-		s = GNOMEUIPIXMAPDIR "/gnome-error.png";
-		if (s) {
-                        pixmap = gtk_image_new_from_file (s);
-                        g_free(s);
-                }
+		pixmap = gtk_image_new_from_stock (GTK_STOCK_DIALOG_ERROR, GTK_ICON_SIZE_DIALOG);
+
 	}
 	else if (strcmp(GNOME_MESSAGE_BOX_QUESTION, message_box_type) == 0)
 	{
                 title_prefix = _("Question");
-		s = GNOMEUIPIXMAPDIR "/gnome-question.png";
-		if (s) {
-                        pixmap = gtk_image_new_from_file (s);
-                        g_free(s);
-                }
+		pixmap = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
 	}
 	else
 	{
@@ -223,15 +209,6 @@ gnome_message_box_construct (GnomeMessageBox       *messagebox,
 			    hbox, TRUE, TRUE, 10);
 	gtk_widget_show (hbox);
 
-	if (pixmap == NULL) {
-        	if (pixmap) gtk_widget_destroy(pixmap);
-		s = GNOMEUIPIXMAPDIR "/gnome-default-dlg.png";
-         	if (s) {
-			pixmap = gtk_image_new_from_file (s);
-                        g_free(s);
-                } else
-			pixmap = NULL;
-	}
 	if (pixmap) {
 		gtk_box_pack_start (GTK_BOX(hbox), 
 				    pixmap, FALSE, TRUE, 0);
@@ -294,7 +271,7 @@ gnome_message_box_new (const gchar           *message,
         
 	va_start (ap, message_box_type);
 	
-	message_box = gtk_type_new (gnome_message_box_get_type ());
+	message_box = gtk_type_new (GNOME_TYPE_MESSAGE_BOX);
 
 	gnome_message_box_construct (message_box, message,
 				     message_box_type, NULL);
@@ -344,7 +321,7 @@ gnome_message_box_newv (const gchar           *message,
 	g_return_val_if_fail (message != NULL, NULL);
 	g_return_val_if_fail (message_box_type != NULL, NULL);
 
-	message_box = gtk_type_new (gnome_message_box_get_type ());
+	message_box = gtk_type_new (GNOME_TYPE_MESSAGE_BOX);
 
 	gnome_message_box_construct (message_box, message,
 				     message_box_type, buttons);
