@@ -31,7 +31,7 @@
  * Author: George Lebl <jirka@5z.com>
  */
 #include <config.h>
-#include "gnome-macros.h"
+#include <libgnome/gnome-macros.h>
 
 #include <sys/stat.h>
 #include <unistd.h>
@@ -68,7 +68,7 @@ struct _GnomePixmapEntryPrivate {
 
 
 static void gnome_pixmap_entry_class_init (GnomePixmapEntryClass *class);
-static void gnome_pixmap_entry_init       (GnomePixmapEntry      *pentry);
+static void gnome_pixmap_entry_instance_init (GnomePixmapEntry      *pentry);
 static void drag_data_get		  (GtkWidget          *widget,
 					   GdkDragContext     *context,
 					   GtkSelectionData   *selection_data,
@@ -100,7 +100,8 @@ enum {
 };
 
 GNOME_CLASS_BOILERPLATE (GnomePixmapEntry, gnome_pixmap_entry,
-			 GnomeFileEntry, gnome_file_entry)
+			 GnomeFileEntry, gnome_file_entry,
+			 GNOME_TYPE_FILE_ENTRY)
 
 static void
 gnome_pixmap_entry_class_init (GnomePixmapEntryClass *class)
@@ -505,7 +506,7 @@ turn_on_previewbox(GnomePixmapEntry *pentry)
 }
 
 static void
-gnome_pixmap_entry_init (GnomePixmapEntry *pentry)
+gnome_pixmap_entry_instance_init (GnomePixmapEntry *pentry)
 {
 	GtkWidget *w;
 	char *p;
@@ -586,7 +587,7 @@ gnome_pixmap_entry_new (const gchar *history_id, const gchar *browse_dialog_titl
 {
 	GnomePixmapEntry *pentry;
 
-	pentry = gtk_type_new (gnome_pixmap_entry_get_type ());
+	pentry = gtk_type_new (GNOME_TYPE_PIXMAP_ENTRY);
 
 	gnome_pixmap_entry_construct (pentry, history_id, browse_dialog_title, do_preview);
 	return GTK_WIDGET (pentry);
