@@ -29,7 +29,7 @@
  */
 
 #include <config.h>
-#include "gnome-macros.h"
+#include <libgnome/gnome-macros.h>
 
 #include <string.h>
 #include <time.h>
@@ -59,7 +59,7 @@ struct _GnomeScoresPrivate
 };
 
 static void gnome_scores_class_init (GnomeScoresClass *klass);
-static void gnome_scores_init       (GnomeScores      *scores);
+static void gnome_scores_instance_init (GnomeScores      *scores);
 static void gnome_scores_destroy    (GtkObject        *object);
 static void gnome_scores_finalize   (GObject          *object);
 
@@ -69,10 +69,10 @@ static void gnome_scores_finalize   (GObject          *object);
  * Returns the GtkType for the GnomeScores widget
  */
 GNOME_CLASS_BOILERPLATE (GnomeScores, gnome_scores,
-			 GtkDialog, gtk_dialog);
+			 GtkDialog, gtk_dialog, GTK_TYPE_DIALOG);
 
 static void 
-gnome_scores_init (GnomeScores *gs)
+gnome_scores_instance_init (GnomeScores *gs)
 {
 	GtkWidget *label;
 
@@ -253,7 +253,7 @@ gnome_scores_new (  guint n_scores,
 		    time_t *times,
 		    gboolean clear)
 {
-	GtkWidget *retval = gtk_type_new(gnome_scores_get_type());
+	GtkWidget *retval = gtk_type_new (GNOME_TYPE_SCORES);
 
 	gnome_scores_construct(GNOME_SCORES(retval), n_scores, names, scores, times, clear);
 
@@ -417,7 +417,7 @@ gnome_scores_set_logo_label (GnomeScores *gs,
 	}
 
 	if(col)
-		memcpy((void *) &s->fg[0], col, sizeof(GdkColor) );
+		s->fg[0] = *col;
 
 	if( font ) 
 		fo = font;
@@ -425,7 +425,7 @@ gnome_scores_set_logo_label (GnomeScores *gs,
 		fo = _("-freefont-garamond-*-*-*-*-30-170-*-*-*-*-*-*,*-r-*");
 
 	if(( f = gdk_fontset_load ( fo ) ))
-		s->font = f;
+		gtk_style_set_font(s, f);
 
 	gs->_priv->logo = gtk_label_new(txt);
 	gtk_widget_set_style(GTK_WIDGET(gs->_priv->logo), s);
