@@ -43,7 +43,7 @@
 /* Must be before all other gnome includes!! */
 #include "gnome-i18nP.h"
 
-#include <libgnome.h>
+#include <libgnome/libgnome.h>
 
 #include "gnome-client.h"
 #include "gnome-gconf-ui.h"
@@ -492,11 +492,11 @@ static void libgnomeui_segv_handle(int signum)
                 program = gnome_program_get();
 
 		/* Child process */
-		execl (GNOMEUIBINDIR "/gnome_segv", GNOMEUIBINDIR "/gnome_segv",
+		execl (GNOMEUIBINDIR "/gnome_segv2", GNOMEUIBINDIR "/gnome_segv",
 		       gnome_program_get_app_id (program), buf,
 		       gnome_program_get_app_version (program), NULL);
 
-                execlp ("gnome_segv", "gnome_segv",
+                execlp ("gnome_segv2", "gnome_segv2",
 			gnome_program_get_app_id (program), buf,
 			gnome_program_get_app_version (program), NULL);
 
