@@ -2,6 +2,14 @@
 /* Generated data (by glib-mkenums) */
 
 
+/* enumerations from "gnome-app-helper.h" */
+    (void) gnome_ui_info_type_get_type ();
+
+    (void) gnome_ui_info_configurable_types_get_type ();
+
+    (void) gnome_ui_pixmap_type_get_type ();
+
+
 /* enumerations from "gnome-client.h" */
     (void) gnome_interact_style_get_type ();
 
@@ -28,19 +36,13 @@
     (void) gnome_icon_list_mode_get_type ();
 
 
+/* enumerations from "gnome-mdi.h" */
+    (void) gnome_mdi_mode_get_type ();
+
+
 /* enumerations from "gnome-types.h" */
     (void) gnome_preferences_type_get_type ();
 
 
-/* enumerations from "gnome-winhints.h" */
-    (void) gnome_win_layer_get_type ();
-
-    (void) gnome_win_state_get_type ();
-
-    (void) gnome_win_hints_get_type ();
-
-    (void) gnome_win_app_state_get_type ();
-
-
 /* Generated data ends here */
 
