@@ -30,6 +30,7 @@
 
 #include <libgnomeui/gnome-uidefs.h>
 
+#include <libgnomeui/gnome-about.h>
 #include <libgnomeui/gnome-app.h>
 #include <libgnomeui/gnome-app-helper.h>
 #include <libgnomeui/gnome-app-util.h>
@@ -50,7 +51,6 @@
 #include <libgnomeui/gnome-icon-list.h>
 #include <libgnomeui/gnome-icon-sel.h>
 #include <libgnomeui/gnome-ui-init.h>
-#include <libgnomeui/gnome-macros.h>
 #include <libgnomeui/gnome-types.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomeui/gnome-scores.h>
